@@ -6,7 +6,7 @@ use warnings;
 use utf8;
 use parent qw/Plack::Component/;
 
-our $VERSION = '0.000_004';
+our $VERSION = '0.000_005';
 
 use DBIx::Simple;
 use File::Slurp;
@@ -62,8 +62,10 @@ sub make_slug {
 	$slug
 }
 
+our %highlight;
 sub form_table_row {
 	my ($data, $tr) = @_;
+	$tr->attr(class => 'highlight') if $highlight{$data->{product}};
 	$tr->fclass($_)->replace_content($data->{$_}) for qw/title subtitle stock/;
 	$tr->fclass('price')->replace_content(stringify_money $data->{price});
 	$tr->fclass('freepost')->detach unless $data->{freepost};
@@ -77,7 +79,9 @@ sub form_table_row {
 sub form_app {
 	my ($env) = @_;
 	$db{$$} //= DBIx::Simple->connect($ENV{OOF_DSN} // 'dbi:Pg:');
+	my $req = Plack::Request->new($env);
 
+	local %highlight = map { $_ => 1 } $req->param('highlight');
 	my $data = $db{$$}->select(products => '*', {}, 'product')->hashes;
 	my $tree = $form->clone;
 	$tree->find('tbody')->find('tr')->iter3($data, \&form_table_row);
@@ -226,14 +230,19 @@ sub details_app {
 	$db{$$} //= DBIx::Simple->connect($ENV{OOF_DSN} // 'dbi:Pg:');
 	my $tree = $details->clone;
 	my ($id) = $env->{PATH_INFO} =~ m,^/(\d+),;
-	my $title = $db{$$}->select(products => 'title', {product => $id})->list;
+	my ($title, $summary) = $db{$$}->select(products => [qw/title summary/], {product => $id})->list;
 	my @pics = <static/fullpics/$id-*>;
 	my $slug = make_slug $title;
 	$tree->find('title')->replace_content("Pictures of $title | ledparts4you");
 	$tree->find('h2')->replace_content($title);
+	$tree->fid('summary')->replace_content($summary);
 	$tree->look_down(rel => 'canonical')->attr(href => "/details/$id/$slug");
 	$tree->fid('pictures')->find('li')->iter3(\@pics, \&details_list_element);
 
+	for my $ahref ($tree->find('a')) {
+		$ahref->attr(href => "/form?highlight=$id") if $ahref->attr('href') eq '/';
+	}
+
 	[200, ['Content-type' => 'text/html; charset=utf-8'], [$tree->as_HTML]]
 }
 
@@ -255,7 +264,7 @@ sub app {
 			my $app = shift;
 			sub {
 				my $res = $app->(@_);
-				push @{$res->[2]}, $footer if $res->[0] == 200;
+				$res->[2][0] =~ s,</body>,$footer</body>, if $res->[0] == 200;
 				$res;
 			}
 		};
